@@ -191,10 +191,10 @@ class BaseAdaptorField(object):
         return self.config.get('auto_width', False)
 
     def get_height(self, widget_options):
-        return int(widget_options.get('height', '0').replace('px', ''))
+        return float(widget_options.get('height', '0').replace('px', ''))
 
     def get_width(self, widget_options):
-        return max(int(widget_options.get('width', '0').replace('px', '')), self.min_width)
+        return max(float(widget_options.get('width', '0').replace('px', '')), self.min_width)
 
     def treatment_height(self, height, width=None):
         if isinstance(height, string) and not height.endswith('px') or not isinstance(height, string):
@@ -276,6 +276,23 @@ class AdaptorURLField(AdaptorTextField):
         value = super(AdaptorURLField, self).render_value(field_name)
         config = deepcopy(self.config)
         context = {'value': value,
+                   'value_link': value,
+                   'obj': self.obj}
+        config.update(context)
+        return render_to_string(template_name, config)
+
+
+class AdaptorEmailField(AdaptorURLField):
+
+    @property
+    def name(self):
+        return 'email'
+
+    def render_value(self, field_name=None, template_name="inplaceeditform/adaptor_url/render_value.html"):
+        value = super(AdaptorURLField, self).render_value(field_name)
+        config = deepcopy(self.config)
+        context = {'value': value,
+                   'value_link': 'mailto:%s' % value,
                    'obj': self.obj}
         config.update(context)
         return render_to_string(template_name, config)
@@ -589,8 +606,6 @@ class AdaptorFileField(BaseAdaptorField):
         if not value:
             return ''
         config = deepcopy(self.config)
-        if self.request.method == 'POST' and config.get('msie', None):
-            config['innerHtml'] = ''
         context = {'value': value,
                    'obj': self.obj}
         config.update(context)
@@ -613,7 +628,4 @@ class AdaptorImageField(AdaptorFileField):
         return super(AdaptorImageField, self).render_media_field(template_name, extra_context=extra_context)
 
     def render_value(self, field_name=None, template_name='inplaceeditform/adaptor_image/render_value.html'):
-        if self.request.method == 'POST' and self.config.get('msie', None):
-            self.config['title'] = ""
-            self.config['alt'] = ""
         return super(AdaptorImageField, self).render_value(field_name=field_name, template_name=template_name)
