@@ -19,6 +19,16 @@
             $(this).show();
         });
     };
+    $.fn.invisible = function () {
+        return this.each(function () {
+            $(this).css("visibility", "hidden");
+        });
+    };
+    $.fn.visible = function () {
+        return this.each(function () {
+            $(this).css("visibility", "visible");
+        });
+    };
     $.fn.inplaceeditform = function (method) {
         var methods = $.inplaceeditform.methods;
 
@@ -31,7 +41,6 @@
         }
         $.error('Method ' + method + ' does not exist on jQuery.inplaceeditform');
     };
-
     $.inplaceeditform = {
         opts: {
             "getFieldUrl": "/inplaceeditform/get_field/",
@@ -40,14 +49,14 @@
             "eventInplaceEdit": "dblclick",
             "disableClick": true,
             "autoSave": false,
-            "unsavedChanges": "You have unsaved changes!",
+            "unsavedChanges": "You have unsaved changes!",  // This is the only opts that can not be overwritten
             "enableClass": "enable"
         },
+        configSelector: "inplaceeditform",
         formSelector: "form.inplaceeditform",
         enabled: false,
         inplaceeditfields: null,
         methods: {},
-
         extend: function (newMethods) {
             this.methods = $.extend(this.methods, newMethods);
         }
@@ -74,290 +83,49 @@
                 }
             }
             this.each(function () {
-                if (self.opts.disableClick) {
-                    $(this).click(function (ev) {
-                        if (self.enabled) {
-                            ev.preventDefault();
-                        }
-                    });
+                var configTag = $(this).find(self.configSelector);
+                var config = configTag.attr();
+                if (self.methods.getOptBool(config, self.opts, 'disableClick')) {
+                    $(this).click(self.methods.disableClickCallBack);
                 }
-                $(this).bind(self.opts.eventInplaceEdit, function () {
-                    if ($(this).data("ajaxTime")) {
-                        return false;
-                    }
-                    if (!self.enabled || !$(this).hasClass(self.opts.enableClass)) {
-                        return false;
-                    }
-                    $(this).data("ajaxTime", true);
-                    var data = self.methods.getDataToRequest($(this).find("inplaceeditform"));
-                    var extraConfig = $(this).find("inplaceeditform").data("extraConfig");
-                    if (extraConfig) {
-                        data = extraConfig(data);
-                    }
-                    var can_auto_save = parseInt($(this).find("inplaceeditform").attr("can_auto_save"));
-                    data += "&__widget_height=" + $(this).innerHeight() + "px" + "&__widget_width=" + $(this).innerWidth() + "px";
-                    var that = this;
-                    $.ajax(
-                        {
-                            data: data,
-                            url: self.opts.getFieldUrl,
-                            type: "GET",
-                            async: true,
-                            dataType: 'json',
-                            error: self.methods.bind(self.methods.treatmentStatusError, {"context": $(this)}),
-                            success: function (response) {
-                                if (!response) {
-                                    alert("The server is down");
-                                } else if (response.errors) {
-                                    alert(response.errors);
-                                } else {
-                                    var tags = $(self.methods.removeStartSpaces(response.field_render));
-                                    $(tags).insertAfter($(that));
-                                    $(that).hide();
-                                    var head = $("head")[0];
-                                    try {
-                                        var medias = $(self.methods.removeStartSpaces(response.field_media_render));
-                                        var medias_preferred = medias.filter("[delay=delay]");
-                                        var medias_regular = medias.not("[delay=delay]");
-                                        $.map(medias_preferred, function (media, i) {
-                                            if (i === 0) {
-                                                self.methods.loadjscssfile(media);
-                                            } else {
-                                                setTimeout(function () {
-                                                    self.methods.loadjscssfile(media);
-                                                }, 500);
-                                            }
-                                        });
-                                        if (medias_preferred.length === 0) {
-                                            $.map(medias_regular, function (media) {
-                                                self.methods.loadjscssfile(media);
-                                            });
-                                        } else {
-                                            setTimeout(function () {
-                                                $.map(medias_regular, function (media) {
-                                                    self.methods.loadjscssfile(media);
-                                                });
-                                            }, 500);
-                                        }
-                                    } catch (err) {
-                                    }
-                                    var links_parents = $(that).next().parents("a");
-                                    if (links_parents.length > 0) {
-                                        $.map(links_parents, function (link) {
-                                            link = $(link);
-                                            var href = link.attr("href");
-                                            link.attr("hrefinplaceedit", href);
-                                            link.addClass("linkInplaceEdit");
-                                            link.removeAttr("href");
-                                        });
-                                    }
-                                    var applyButton = $(that).next().find(".apply");
-                                    var cancelButton = $(that).next().find(".cancel");
-                                    var applyFileButton = $(that).next().find(".applyFile");
-                                    if (cancelButton.size()) {
-                                        cancelButton.click(self.methods.inplaceCancel);
-                                    }
-                                    if (applyButton.size()) {
-                                        applyButton.click(self.methods.inplaceApply);
-                                        $(that).next(self.formSelector).submit(self.methods.bind(self.methods.inplaceApply, applyButton));
-                                    }
-                                    if (applyFileButton.size()) {
-                                        applyFileButton.click(self.methods.inplaceApplyUpload);
-                                        $(that).next(self.formSelector).submit(self.methods.bind(self.methods.inplaceApply, applyFileButton));
-                                    }
-                                    $(that).next(self.formSelector).find("input, select, textarea").focus();
-                                    if (self.opts.autoSave && can_auto_save) {
-                                        applyButton.hide();
-                                        cancelButton.hide();
-                                        applyFileButton.hide();
-                                        var value = $(that).next(self.formSelector).find("input, select, textarea").val();
-                                        var autoSave = function () {
-                                            var newValue = $(this).val();
-                                            if (newValue !== value) {
-                                                $(that).next(self.formSelector).find(".apply").click();
-                                            } else {
-                                                $(that).next(self.formSelector).find(".cancel").click();
-                                            }
-                                        };
-                                        $(that).next(self.formSelector).find("input, select, textarea").blur(autoSave);
-                                        $(that).next(self.formSelector).find("select").change(autoSave);
-                                    }
-                                }
-                                $(that).data("ajaxTime", false);
-                            }
-                        }
-                    );
-                });
+                $(this).bind(self.methods.getOpt(config, self.opts, 'eventInplaceEdit'), self.methods.eventInplaceEditCallBack);
             });
-            window.onbeforeunload = function (event) {
-                var msg = undefined;
-                if ($(self.formSelector).size()) {
-                    if (!self.isMsIE || (window.couldCatch && !(window.newLocation.indexOf("javascript:") === 0))) {
-                        msg = self.opts.unsavedChanges;
-                        if (event) {
-                            // For IE and Firefox prior to version 4
-                            event.returnValue = msg;
-                        }
-                    }
-                }
-                window.couldCatch = false;
-                window.newLocation = null;
-                return msg;
-            };
-
-            // https://docs.djangoproject.com/en/1.3/ref/contrib/csrf/#ajax
-            $(document).ajaxSend(function (event, xhr, settings) {
-                function getCookie(name) {
-                    var cookieValue = null;
-                    var i;
-                    if (document.cookie && document.cookie !== '') {
-                        var cookies = document.cookie.split(';');
-                        for (i = 0; i < cookies.length; i += 1) {
-                            var cookie = $.trim(cookies[i]);
-                            // Does this cookie string begin with the name we want?
-                            if (cookie.substring(0, name.length + 1) === (name + '=')) {
-                                cookieValue = decodeURIComponent(cookie.substring(name.length + 1));
-                                break;
-                            }
-                        }
-                    }
-                    return cookieValue;
-                }
-
-                function sameOrigin(url) {
-                    // url could be relative or scheme relative or absolute
-                    var host = document.location.host; // host + port
-                    var protocol = document.location.protocol;
-                    var sr_origin = '//' + host;
-                    var origin = protocol + sr_origin;
-                    // Allow absolute or scheme relative URLs to same origin
-                    return (url === origin || url.slice(0, origin.length + 1) === origin + '/') ||
-                        (url === sr_origin || url.slice(0, sr_origin.length + 1) === sr_origin + '/') ||
-                        // or any other URL that isn't scheme relative or absolute i.e relative.
-                        !(/^(\/\/|http:|https:).*/.test(url));
-                }
-
-                function safeMethod(settings) {
-                    return (/^(GET|HEAD|OPTIONS|TRACE)$/.test(settings.type)) || settings.url.indexOf("send_csrfToken") > -1;
-                }
-
-                if (!safeMethod(settings) && sameOrigin(settings.url)) {
-                    xhr.setRequestHeader("X-CSRFToken", getCookie('csrftoken'));
-                }
-            });
-
+            window.onbeforeunload = self.methods.onBeforeUnloadEvent;
             return {
                 enable: function () {
                     self.enabled = true;
                     self.inplaceeditfields.each(function () {
-                        $(this).addClass(self.opts.enableClass);
+                        var configTag = $(this).find(self.configSelector);
+                        var config = configTag.attr();
+                        var enableClass = self.methods.getOpt(config, self.opts, 'enableClass');
+                        $(this).addClass(enableClass);
                     });
                 },
                 disable: function () {
                     self.enabled = false;
                     self.inplaceeditfields.each(function () {
-                        $(this).removeClass(self.opts.enableClass);
+                        var configTag = $(this).find(self.configSelector);
+                        var config = configTag.attr();
+                        var enableClass = self.methods.getOpt(config, self.opts, 'enableClass');
+                        $(this).removeClass(enableClass);
                     });
                 }
             };
         },
-
-        treatmentStatusError: function (response) {
-            if (response.status === 0) {
-                alert("The server is down");
-            } else if (response.status === 403) {
-                alert("Permission denied, please check that you are login");
+        appendChild: function (node, text) {
+            if (null === node.canHaveChildren || node.canHaveChildren) {
+                node.appendChild(document.createTextNode(text));
             } else {
-                alert(response.statusText);
+                node.text = text;
             }
-            this.context.next(".cancel").click();
-            this.context.data("ajaxTime", false);
         },
-
-        revertlinkInplaceEdit: function (links_parents) {
-            $.map(links_parents, function (link) {
-                link = $(link);
-                var href = link.attr("hrefinplaceedit");
-                link.attr("href", href);
-                link.removeClass("linkInplaceEdit");
-                link.removeAttr("hrefinplaceedit");
-            });
-        },
-
-        inplaceCancel: function () {
+        autoSaveCallBack: function () {
             var self = $.inplaceeditform;
-            self.methods.revertlinkInplaceEdit($(this).parents("a.linkInplaceEdit"));
-            $(this).parent().prev().fadeIn();
-            var cancelFinish = $(this).data("cancelFinish");
-            if (cancelFinish) {
-                cancelFinish();
-            }
-            $(this).parent().remove();
-            return false;
-        },
-
-        replaceAll: function (txt, replace, with_this) {
-            return txt.replace(new RegExp(replace, "g"), with_this);
-        },
-
-        inplaceApplySuccess: function (response) {
-            var self = $.inplaceeditform;
-            if (typeof response === "string") {
-                if (self.isMsIE) {
-                    response = self.methods.replaceAll(response, "'\\\\\"", "'");
-                    response = self.methods.replaceAll(response, "\"'", "'");
-                }
-                try {
-                    response = JSON.parse(response);
-                } catch (errno) {
-                    response = eval("( " + response + " )");
-                }
-            }
-            self.methods.revertlinkInplaceEdit($(this.form).parents("a.linkInplaceEdit"));
-            var that = this.context;
-            var form = this.form;
-            var inplaceedit_conf = this.inplaceedit_conf;
-            if (!response) {
-                alert("The server is down");
-            } else if (response.errors) {
-                form.animate({opacity: 1});
-                form.prepend("<ul class='errors'><li>" + response.errors + "</li></ul>");
+            var newValue = this.tag.val();
+            if (newValue !== this.oldValue) {
+                this.tag.parents(self.formSelector).find(".apply").click();
             } else {
-                that.parent().fadeOut();
-                that.fadeIn();
-                form.removeClass("inplaceeditformsaving");
-                var inplace_span = inplaceedit_conf.parents(".inplaceedit");
-                var config = inplace_span.find("inplaceeditform").attr();
-                var config_html = "<inplaceeditform";
-                var attr;
-                for (attr in config) {
-                    config_html += ' ' + attr + '="' + config[attr] + '"';
-                }
-                config_html += "></inplaceeditform>";
-                inplace_span.html(response.value + config_html);
-                inplace_span.css("display", "");
-                self.methods.inplaceApplySuccessShowMessage(inplace_span, response);
-                var applyFinish = that.data("applyFinish");
-                if (applyFinish) {
-                    applyFinish(that);
-                }
-                that.parent().remove();
-            }
-        },
-
-        inplaceApplySuccessShowMessage: function (inplace_span) {
-            var self = $.inplaceeditform;
-            if (self.opts.successText) {
-                var success_message = $("<ul class='success'><li>" + self.opts.successText + "</li></ul>");
-                inplace_span.prepend(success_message);
-                inplace_span.removeClass(self.opts.enableClass);
-                setTimeout(function () {
-                    success_message.fadeOut(function () {
-                        $(this).remove();
-                        inplace_span.redraw();
-                        inplace_span.addClass(self.opts.enableClass);
-                    });
-                }, 2000);
+                this.tag.parents(self.formSelector).find(".cancel").click();
             }
         },
         bind: function (func, that) {
@@ -365,18 +133,93 @@
                 return func.apply(that, arguments);
             };
         },
+        disableClickCallBack: function (ev) {
+            var self = $.inplaceeditform;
+            if (self.enabled) {
+                ev.preventDefault();
+            }
+        },
+        eventInplaceEditCallBack: function () {
+            var self = $.inplaceeditform;
+            if ($(this).data("ajaxTime")) {
+                return false;
+            }
+            if (!self.enabled || !$(this).hasClass(self.opts.enableClass)) {
+                return false;
+            }
+            var configTag = $(this).find(self.configSelector);
+            var config = configTag.attr();
+            $(this).data("ajaxTime", true);
+            var data = self.methods.getDataToRequest(configTag);
+            var extraConfig = configTag.data("extraConfig");
+            if (extraConfig) {
+                data = extraConfig(data);
+            }
+            data += "&__widget_height=" + $(this).innerHeight() + "px" + "&__widget_width=" + $(this).innerWidth() + "px";
+            $.ajax({
+                data: data,
+                url: self.methods.getOpt(config, self.opts, 'getFieldUrl'),
+                type: "GET",
+                async: true,
+                dataType: 'json',
+                error: self.methods.bind(self.methods.treatmentStatusError, {"context": $(this)}),
+                success: self.methods.bind(self.methods.inplaceGetFieldSuccess, {"that": this})
+            });
+        },
         getCSFRToken: function () {
             return csrf_token;
         },
+        getDataToRequest: function (configTag) {
+            var dataToRequest = "";
+            var settings = configTag.attr();
+            $.map(settings, function (value, key) {
+                var data = "";
+                if (dataToRequest !== "") {
+                    data = "&";
+                }
+                data += key + "=" + value;
+                dataToRequest += data;
+            });
+            var fontSize = configTag.parent().css("font-size");
+            if (fontSize) {
+                dataToRequest += "&font_size=" + fontSize;
+            }
+            return dataToRequest;
+        },
+        getDataToRequestUpload: function (configTag) {
+            var dataToRequest = configTag.attr();
+            var fontSize = configTag.parent().css("font-size");
+            if (fontSize) {
+                dataToRequest.font_size = fontSize;
+            }
+            return dataToRequest;
+        },
+        getOpt: function (config, genericOpts, opt) {
+            return (config[opt.toLowerCase()] !== undefined && config[opt.toLowerCase()]) || genericOpts[opt];
+        },
+        getOptBool: function (config, genericOpts, opt) {
+            var self = $.inplaceeditform;
+            var val = self.methods.getOpt(config, genericOpts, opt);
+            if (typeof val === "string") {
+                val = parseInt(val);
+            }
+            return val;
+        },
         inplaceApply: function () {
             var self = $.inplaceeditform;
             var form = $(this).parents(self.formSelector);
-            form.animate({opacity: 0.1});
+            if (form.data("ajaxTime")) {
+                return
+            }
+            form.animate({opacity: 0.1}, function () {
+                form.find(".apply, .cancel").invisible();
+            });
             form.find("ul.errors").fadeOut(function () {
                 $(this).remove();
             });
-            var inplaceedit_conf = form.prev().find("inplaceeditform");
-            var data = self.methods.getDataToRequest(inplaceedit_conf);
+            var configTag = form.prev().find(self.configSelector);
+            var config = configTag.attr();
+            var data = self.methods.getDataToRequest(configTag);
             var field_id = form.find("span.field_id").html();
             var getValue = $(this).data("getValue"); // A hook
             var value;
@@ -390,10 +233,9 @@
             if (csrfmiddlewaretoken) {
                 data += "&csrfmiddlewaretoken=" + csrfmiddlewaretoken;
             }
-            $.ajax(
-                {
-                    data: data,
-                    url: self.opts.saveURL,
+            form.data("ajaxTime", true);
+            $.ajax({data: data,
+                    url: self.methods.getOpt(config, self.opts, 'saveURL'),
                     type: "POST",
                     async: true,
                     dataType: 'text',
@@ -401,22 +243,26 @@
                     success: self.methods.bind(self.methods.inplaceApplySuccess, {
                         "context": $(this),
                         "form": form,
-                        "inplaceedit_conf": inplaceedit_conf
+                        "configTag": configTag
                     })
-                }
-            );
+            });
             return false;
         },
-
         inplaceApplyUpload: function () {
             var self = $.inplaceeditform;
             var form = $(this).parents(self.formSelector);
-            form.animate({opacity: 0.1});
+            if (form.data("ajaxTime")) {
+                return
+            }
+            form.animate({opacity: 0.1}, function() {
+                form.find(".applyFile, .cancel").invisible();
+            });
             form.find("ul.errors").fadeOut(function () {
                 $(this).remove();
             });
-            var inplaceedit_conf = form.prev().find("inplaceeditform");
-            var data = self.methods.getDataToRequestUpload(inplaceedit_conf);
+            var configTag = form.prev().find(self.configSelector);
+            var config = configTag.attr();
+            var data = self.methods.getDataToRequestUpload(configTag);
             var csrfmiddlewaretoken = self.methods.getCSFRToken();
             if (csrfmiddlewaretoken) {
                 data.csrfmiddlewaretoken = csrfmiddlewaretoken;
@@ -430,60 +276,189 @@
                 value = form.find("#" + field_id).val();
             }
             data.value = encodeURIComponent($.toJSON(value));
-            if (self.isMsIE) {
-                data.msie = true;
-            }
-            form.ajaxSubmit(
-                {
-                    url: self.opts.saveURL,
-                    data: data,
-                    async: true,
-                    type: "POST",
-                    method: "POST",
-                    dataType: "application/json",
-                    error: self.methods.bind(self.methods.treatmentStatusError, {"context": $(this)}),
-                    success: self.methods.bind(self.methods.inplaceApplySuccess, {
-                        "context": $(this),
-                        "form": form,
-                        "inplaceedit_conf": inplaceedit_conf
-                    })
-                }
-            );
+            form.data("ajaxTime", true);
+            form.ajaxSubmit({url: self.methods.getOpt(config, self.opts, 'saveURL'),
+                             data: data,
+                             async: true,
+                             type: "POST",
+                             method: "POST",
+                             dataType: "json",
+                             error: self.methods.bind(self.methods.treatmentStatusError, {"context": $(this)}),
+                             success: self.methods.bind(self.methods.inplaceApplySuccess, {
+                                "context": $(this),
+                                "form": form,
+                                "configTag": configTag
+                             })
+            });
             return false;
         },
-
-        getDataToRequest: function (inplaceedit_conf) {
-            var dataToRequest = "";
-            var settings = inplaceedit_conf.attr();
-            $.map(settings, function (value, key) {
-                var data = "";
-                if (dataToRequest !== "") {
-                    data = "&";
+        inplaceApplySuccess: function (response) {
+            var self = $.inplaceeditform;
+            var that = this.context;
+            var form = this.form;
+            form.data("ajaxTime", false);
+            if (typeof response === "string") {
+                if (self.isMsIE) {
+                    response = self.methods.replaceAll(response, "'\\\\\"", "'");
+                    response = self.methods.replaceAll(response, "\"'", "'");
+                }
+                try {
+                    response = JSON.parse(response);
+                } catch (errno) {
+                    try {
+                        response = eval("( " + response + " )");
+                    } catch (errno2) {
+                        alert(errno2);
+                        return;
+                    }
                 }
-                data += key + "=" + value;
-                dataToRequest += data;
-            });
-            var fontSize = inplaceedit_conf.parent().css("font-size");
-            if (fontSize) {
-                dataToRequest += "&font_size=" + fontSize;
             }
-            return dataToRequest;
-        },
-
-        getDataToRequestUpload: function (inplaceedit_conf) {
-            var dataToRequest = inplaceedit_conf.attr();
-            var fontSize = inplaceedit_conf.parent().css("font-size");
-            if (fontSize) {
-                dataToRequest.font_size = fontSize;
+            self.methods.revertlinkInplaceEdit($(this.form).parents("a.linkInplaceEdit"));
+            var configTag = this.configTag;
+            var inplace_span = configTag.parents(".inplaceedit");
+            var config = inplace_span.find(self.configSelector).attr();
+            if (!response) {
+                alert("The server is down");
+            } else if (response.errors) {
+                if (!self.methods.getOptBool(config, self.opts, "autoSave") || !parseInt(config.can_auto_save)) {
+                    form.find(".apply, .applyFile, .cancel").visible();
+                }
+                form.animate({opacity: 1});
+                form.prepend("<ul class='errors'><li>" + response.errors + "</li></ul>");
+            } else {
+                that.parent().fadeOut();
+                that.fadeIn();
+                form.removeClass("inplaceeditformsaving");
+                var config_html = "<" + self.configSelector;
+                var attr;
+                for (attr in config) {
+                    config_html += ' ' + attr + '="' + config[attr] + '"';
+                }
+                config_html += "></" + self.configSelector + ">";
+                inplace_span.html(response.value + config_html);
+                inplace_span.css("display", "");
+                self.methods.inplaceApplySuccessShowMessage(inplace_span, response);
+                var applyFinish = that.data("applyFinish");
+                if (applyFinish) {
+                    applyFinish(that);
+                }
+                that.parent().remove();
             }
-            return dataToRequest;
         },
-
-        removeStartSpaces: function (html) {
-            // Remove the espaces and \n to the begin of the field_render
-            return html.replace(/^( |\n)*/g, "");
+        inplaceApplySuccessShowMessage: function (inplace_span) {
+            var self = $.inplaceeditform;
+            var configTag = inplace_span.find(self.configSelector);
+            var config = configTag.attr();
+            var successText = self.methods.getOpt(config, self.opts, 'successText');
+            if (successText) {
+                var success_message = $("<ul class='success'><li>" + successText + "</li></ul>");
+                inplace_span.prepend(success_message);
+                inplace_span.removeClass(self.opts.enableClass);
+                setTimeout(function () {
+                    success_message.fadeOut(function () {
+                        $(this).remove();
+                        inplace_span.redraw();
+                        if (self.enabled) {
+                            inplace_span.addClass(self.opts.enableClass);
+                        }
+                    });
+                }, 2000);
+            }
+        },
+        inplaceCancel: function () {
+            var self = $.inplaceeditform;
+            self.methods.revertlinkInplaceEdit($(this).parents("a.linkInplaceEdit"));
+            $(this).parent().prev().fadeIn();
+            var cancelFinish = $(this).data("cancelFinish");
+            if (cancelFinish) {
+                cancelFinish();
+            }
+            $(this).parents(self.formSelector).remove();
+            return false;
+        },
+        inplaceGetFieldSuccess: function(response) {
+            var self = $.inplaceeditform;
+            if (!response) {
+                alert("The server is down");
+            } else if (response.errors) {
+                alert(response.errors);
+            } else {
+                var that = this.that;
+                var configTag = $(that).find(self.configSelector);
+                var config = configTag.attr();
+                var tags = $(self.methods.removeStartSpaces(response.field_render));
+                $(tags).insertAfter($(that));
+                $(that).hide();
+                var head = $("head")[0];
+                try {
+                    var medias = $(self.methods.removeStartSpaces(response.field_media_render));
+                    var medias_preferred = medias.filter("[delay=delay]");
+                    var medias_regular = medias.not("[delay=delay]");
+                    $.map(medias_preferred, function (media, i) {
+                        if (i === 0) {
+                            self.methods.loadjscssfile(media);
+                        } else {
+                            setTimeout(function () {
+                                self.methods.loadjscssfile(media);
+                            }, 500);
+                        }
+                    });
+                    if (medias_preferred.length === 0) {
+                        $.map(medias_regular, function (media) {
+                            self.methods.loadjscssfile(media);
+                        });
+                    } else {
+                        setTimeout(function () {
+                            $.map(medias_regular, function (media) {
+                                self.methods.loadjscssfile(media);
+                            });
+                        }, 500);
+                    }
+                } catch (err) {
+                }
+                var links_parents = $(that).next().parents("a");
+                if (links_parents.length > 0) {
+                    $.map(links_parents, function (link) {
+                        link = $(link);
+                        var href = link.attr("href");
+                        link.attr("hrefinplaceedit", href);
+                        link.addClass("linkInplaceEdit");
+                        link.removeAttr("href");
+                    });
+                }
+                var applyButton = $(that).next().find(".apply");
+                var cancelButton = $(that).next().find(".cancel");
+                var applyFileButton = $(that).next().find(".applyFile");
+                if (cancelButton.size()) {
+                    cancelButton.click(self.methods.inplaceCancel);
+                }
+                if (applyButton.size()) {
+                    applyButton.click(self.methods.inplaceApply);
+                    $(that).next(self.formSelector).submit(self.methods.bind(self.methods.inplaceApply, applyButton));
+                }
+                if (applyFileButton.size()) {
+                    applyFileButton.click(self.methods.inplaceApplyUpload);
+                    $(that).next(self.formSelector).submit(self.methods.bind(self.methods.inplaceApplyUpload, applyFileButton));
+                }
+                var fieldTag = $(that).next(self.formSelector).find("input, select, textarea");
+                fieldTag.focus();
+                if (self.methods.getOptBool(config, self.opts, "autoSave") && parseInt(config.can_auto_save)) {
+                    applyButton.hide();
+                    cancelButton.hide();
+                    applyFileButton.hide();
+                    var value = fieldTag.val();
+                    fieldTag.blur(
+                        self.methods.bind(self.methods.autoSaveCallBack, {"oldValue": value,
+                                                                          "tag": fieldTag})
+                    );
+                    $(that).next(self.formSelector).find("select").change(
+                        self.methods.bind(self.methods.autoSaveCallBack, {"oldValue": value,
+                                                                          "tag": fieldTag})
+                    );
+                }
+            }
+            $(that).data("ajaxTime", false);
         },
-
         loadjscssfile: function (media) {
             var self = $.inplaceeditform;
             var fileref;
@@ -509,13 +484,48 @@
                 document.getElementsByTagName("head")[0].appendChild(fileref);
             }
         },
-        appendChild: function (node, text) {
-            if (null === node.canHaveChildren || node.canHaveChildren) {
-                node.appendChild(document.createTextNode(text));
-            } else {
-                node.text = text;
+        onBeforeUnloadEvent: function (event) {
+            var msg = undefined;
+            var self = $.inplaceeditform;
+            if ($(self.formSelector).size()) {
+                if (!self.isMsIE || (window.couldCatch && !(window.newLocation.indexOf("javascript:") === 0))) {
+                    msg = self.opts.unsavedChanges;
+                    if (event) {
+                        // For IE and Firefox prior to version 4
+                        event.returnValue = msg;
+                    }
+                }
             }
+            window.couldCatch = false;
+            window.newLocation = null;
+            return msg;
+        },
+        removeStartSpaces: function (html) {
+            // Remove the espaces and \n to the begin of the field_render
+            return html.replace(/^( |\n)*/g, "");
+        },
+        replaceAll: function (txt, replace, with_this) {
+            return txt.replace(new RegExp(replace, "g"), with_this);
+        },
+        revertlinkInplaceEdit: function (links_parents) {
+            $.map(links_parents, function (link) {
+                link = $(link);
+                var href = link.attr("hrefinplaceedit");
+                link.attr("href", href);
+                link.removeClass("linkInplaceEdit");
+                link.removeAttr("hrefinplaceedit");
+            });
+        },
+        treatmentStatusError: function (response) {
+            if (response.status === 0) {
+                alert("The server is down");
+            } else if (response.status === 403) {
+                alert("Permission denied, please check that you are login");
+            } else {
+                alert("Some error. Status text =" + response.statusText);
+            }
+            this.context.next(".cancel").click();
+            this.context.data("ajaxTime", false);
         }
     });
 })(jQuery);
-
